@@ -1,8 +1,10 @@
 #!/usr/bin/python
 from urllib import urlencode
 import httplib2
+import argparse
 import re
 import sys
+import getpass
 import os
 import os.path
 import json
@@ -14,7 +16,40 @@ try:
 except ImportError:
     from json import loads, dumps
 
-client_id = sys.argv[1];
+parser = argparse.ArgumentParser(description=
+   'Python Docker ISet using FullAuto API.')
+parser.add_argument('clientid')
+parser.add_argument('pem_file',nargs='?',default='fullauto.pem')
+args=parser.parse_args()
+client_id = args.clientid;
+
+pem_file_path='';
+from os.path import expanduser
+home = expanduser("~")
+cwd = os.getcwd()
+if os.path.isfile(args.pem_file) and os.access(args.pem_file, os.R_OK):
+    pem_file_path=cwd+'/'+args.pem_file
+    os.chmod(pem_file_path,0777)
+    print pem_file_path+" exists and is readable"
+elif os.path.isfile(home+'/'+args.pem_file) and \
+       os.access(home+args.pem_file, os.R_OK):
+    pem_file_path=home+args.pem_file
+    os.chmod(pem_file_path,0777)
+    print pem_file_path+" exists and is readable"
+elif os.path.isfile('/cygdrive/c/Users/'+username+'/Desktop/'+args.pem_file) \
+       and os.access('/cygdrive/c/Users/'+username+'/Desktop/'+args.pem_file, \
+       os.R_OK):
+    pem_file_path='/cygdrive/c/Users/'+username+'/Desktop/'+args.pem_file
+    os.chmod(pem_file_path,0777)
+    print pem_file_path+"\nexists and is readable"
+else:
+    print pem_file_path+" is missing or is not readable"
+    sys.exit()
+with open(pem_file_path,'rb') as f:
+    pemfile = f.read()
+print pemfile
+
+username = getpass.getuser();
 http = httplib2.Http(disable_ssl_certificate_validation=True)
 http.follow_redirects = False
 url = "https://localhost/request?client_id=" + client_id \
@@ -34,6 +69,7 @@ if os.path.isfile(PATH) and os.access(PATH, os.R_OK):
     print PATH+" exists and is readable"
 else:
     print PATH+" is missing or is not readable"
+    sys.exit()
 with open(PATH) as f:
     for line in f:
         items=line.split(',');
@@ -71,6 +107,8 @@ for inst in result['Reservations']:
    else:
       continue
    break
+print "\n   Waiting for 3 seconds . . .\n"
+time.sleep( 3 )
 gid      = elem['SecurityGroups'][0]['GroupId']
 sid      = elem['SubnetId']
 headers  = {'Content-Type': 'application/json','Authorization': bearer }
@@ -95,15 +133,8 @@ new_sg   = 'aws ec2 create-security-group --group-name ' + \
 ingress  = 'aws ec2 authorize-security-group-ingress ' + \
            '--group-name DockerSecurityGroup --protocol tcp ' + \
            '--port 22 --cidr ' + cidr + ' 2>&1'
-PATH='fullauto.pem'
+
 print ingress
-if os.path.isfile(PATH) and os.access(PATH, os.R_OK):
-    print PATH+" exists and is readable"
-else:
-    print PATH+" is missing or is not readable"
-with open(PATH,'rb') as f:
-    pemfile = f.read()
-print pemfile
 
 # http://mancoosi.org/~abate/upload-file-using-httplib
 def upload(url,filename,bearer):
@@ -143,12 +174,15 @@ def upload(url,filename,bearer):
         httpx = httplib2.Http(disable_ssl_certificate_validation=True)
         httpx.request(url,'POST', body, headers)
 
-upload(url,'/home/Administrator/FullAutoAPI/fullauto.pem',bearer)
+upload(url,pem_file_path,bearer)
+
+#sys.exit()
 
 time.sleep( 1 )
 
-data = {'cmd': [['cmd','mv /tmp/fullauto.pem /home/Administrator/FullAutoAPI'],
-                ['cwd','/home/Administrator/FullAutoAPI'],
+data = {'cmd': [['cmd','mv /tmp/'+pem_file_path+
+                 ' '+home+'/FullAutoAPI'],
+                ['cwd',home+'/FullAutoAPI'],
                 ['cmd','chmod 400 fullauto.pem'],
                 ['cmd',new_sg],
                 ['cmd',ingress]]}
@@ -199,17 +233,18 @@ print docker_ip
 data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':'fullauto.pem','noretry':'1'}]]}
 time.sleep( 1 )
 docker_server1='';
+print "\nGoing to Attempt to Connect to new Docker Server via ssh . . .\n"
 while loop == 1: # This creates an infinite loop
-   print "GOING FOR CONNECT"
    headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
    result = json.loads(content)
    result = json.loads(result['result'])
    if re.search('Connection timed out|Connection refused',result[0][1]):
-      print result[0][1]
-      time.sleep( 1 )
+      #print result[0][1]
+      print "\n   Waiting for sshd service to start . . .\n"
+      time.sleep( 3 )
       continue
    else:
-      print "GOT DOCKER!!!!"
+      print "GOT DOCKER!!!!"+result[0][1]
       docker_server1=result[0][0]
    break
 time.sleep( 1 )
